function Tres = wleit2(Ts, s, steps)
% wleit - Wärmeleitung mit FTCS
%   Ts: Anfangswerte der Temperatur
%   s: Integrationskoeffizient (kappa * dt / dx^2)
%   steps: Anzahl der zu integrierenden Zeitschritte
n = length(Ts);

Tres = Ts;
% Randwerte für den ersten Schritt "glätten"
Tres(1) = .5 * (Tres(1) + Tres(2));
Tres(n) = .5 * (Tres(n-1) + Tres(n));
for k = 1:steps
  Tres(2:n-1) = s * Tres(1:n-2) + (1 - 2*s) * Tres(2:n-1) + s * Tres(3:n) ;
  % Randwerte setzen (const)
  Tres(1) = Ts(1);
  Tres(n) = Ts(n);
end

%% EOF
